﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using Infragistics.Win.UltraWinGrid;

namespace IsItemInList_Workaround
{
    public partial class Form1 : Form
    {
        DataTable dt = new DataTable();
        public Form1()
        {
            InitializeComponent();

            #region Populate the Combo with Data
            dt.Columns.Add("ID", typeof(int));
            dt.Columns["ID"].AutoIncrement = true;
            dt.Columns.Add("Text", typeof(string));

            dt.Rows.Add(new object[] { null, "Apple" });
            dt.Rows.Add(new object[] { null, "Banana" });
            dt.Rows.Add(new object[] { null, "Cherry" });

            this.ultraCombo1.DataSource = dt;
            this.ultraCombo1.ValueMember = "ID";
            this.ultraCombo1.DisplayMember = "Text";
            #endregion // Populate the Combo with Data
        }

        private void ultraCombo1_ItemNotInList(object sender, Infragistics.Win.UltraWinEditors.ValidationErrorEventArgs e)
        {
            UltraCombo combo = (UltraCombo)sender;

            // Turn off the ValueChanged event so it doesn't fire for the temporary object
            // we are about to assign to it. 
            //
            combo.EventManager.SetEnabled(ComboEventIds.ValueChanged, false);

            try
            {

                // Showing a MessageBox here when the item is not on the list will cause the Combo to lose
                // focus and try to match the current Text with the ValueMember. 
                // To avoid that and keep the same text, we will set the Value temporarily to an object that
                // cannot possibly match any items on the list, but shows the same text. 
                TempObject tempObject = new TempObject(e.InvalidText);
                combo.Value = tempObject;
            }
            finally
            {
                // Re-enabled the ValueChanged event.
                //
                combo.EventManager.SetEnabled(ComboEventIds.ValueChanged, true);
            }

            // Prompt the user to add a new item. 
            DialogResult result = MessageBox.Show(
                this, 
                string.Format("The text you have entered: '{0}' is not on the list. Would you like to add a new item?", e.InvalidText),
                "Add new Item",
                MessageBoxButtons.YesNo);

            switch (result)
            {
                case DialogResult.No:
                    // The user doesn't want to add the item, so just set the value back to the
                    // original value. 
                    //
                    combo.Value = e.LastValidValue;
                    break;
                case DialogResult.Yes:
                    // The user wants to add it. Add the new item and set the Combo's Value. 
                    //
                    DataRow dr = dt.Rows.Add(new object[] { null, e.InvalidText });
                    combo.Value = dr["ID"];
                    break;                    
            }
        }

        // An object that displays as a string. 
        public class TempObject
        {
            string displayText;

            public TempObject(string displayText)
            {
                this.displayText = displayText;
            }

            public override string ToString()
            {
                return this.displayText;
            }
        }

        private void ultraCombo1_ValueChanged(object sender, EventArgs e)
        {
            
        }
    }
}
